@@ -23,6 +23,7 @@ from enum import Enum
 if typing.TYPE_CHECKING:
     from typing import Dict, List, Optional, Union
     from datetime import datetime
+    from ask_sdk_model.slot_value import SlotValue
     from ask_sdk_model.slu.entityresolution.resolutions import Resolutions
     from ask_sdk_model.slot_confirmation_status import SlotConfirmationStatus
 
@@ -36,27 +37,31 @@ class Slot(object):
     :type value: (optional) str
     :param confirmation_status: Indication of whether an intent or slot has been explicitly confirmed or denied by the user, or neither.
     :type confirmation_status: (optional) ask_sdk_model.slot_confirmation_status.SlotConfirmationStatus
-    :param resolutions: Contains the results of entity resolution. These are organized by authority. An authority represents the source for the data provided for the slot. For a custom slot type, the authority is the slot type you defined.
+    :param resolutions: Contains the resultsof entity resolution. These are organized by authority. An authority represents the source for the data provided for the slot. For a custom slot type, the authority is the slot type you defined.
     :type resolutions: (optional) ask_sdk_model.slu.entityresolution.resolutions.Resolutions
+    :param slot_value: Object representing the value of the slot.
+    :type slot_value: (optional) ask_sdk_model.slot_value.SlotValue
 
     """
     deserialized_types = {
         'name': 'str',
         'value': 'str',
         'confirmation_status': 'ask_sdk_model.slot_confirmation_status.SlotConfirmationStatus',
-        'resolutions': 'ask_sdk_model.slu.entityresolution.resolutions.Resolutions'
+        'resolutions': 'ask_sdk_model.slu.entityresolution.resolutions.Resolutions',
+        'slot_value': 'ask_sdk_model.slot_value.SlotValue'
     }  # type: Dict
 
     attribute_map = {
         'name': 'name',
         'value': 'value',
         'confirmation_status': 'confirmationStatus',
-        'resolutions': 'resolutions'
+        'resolutions': 'resolutions',
+        'slot_value': 'slotValue'
     }  # type: Dict
     supports_multiple_types = False
 
-    def __init__(self, name=None, value=None, confirmation_status=None, resolutions=None):
-        # type: (Optional[str], Optional[str], Optional[SlotConfirmationStatus], Optional[Resolutions]) -> None
+    def __init__(self, name=None, value=None, confirmation_status=None, resolutions=None, slot_value=None):
+        # type: (Optional[str], Optional[str], Optional[SlotConfirmationStatus], Optional[Resolutions], Optional[SlotValue]) -> None
         """
 
         :param name: A string that represents the name of the slot.
@@ -65,8 +70,10 @@ class Slot(object):
         :type value: (optional) str
         :param confirmation_status: Indication of whether an intent or slot has been explicitly confirmed or denied by the user, or neither.
         :type confirmation_status: (optional) ask_sdk_model.slot_confirmation_status.SlotConfirmationStatus
-        :param resolutions: Contains the results of entity resolution. These are organized by authority. An authority represents the source for the data provided for the slot. For a custom slot type, the authority is the slot type you defined.
+        :param resolutions: Contains the resultsof entity resolution. These are organized by authority. An authority represents the source for the data provided for the slot. For a custom slot type, the authority is the slot type you defined.
         :type resolutions: (optional) ask_sdk_model.slu.entityresolution.resolutions.Resolutions
+        :param slot_value: Object representing the value of the slot.
+        :type slot_value: (optional) ask_sdk_model.slot_value.SlotValue
         """
         self.__discriminator_value = None  # type: str
 
@@ -74,6 +81,7 @@ class Slot(object):
         self.value = value
         self.confirmation_status = confirmation_status
         self.resolutions = resolutions
+        self.slot_value = slot_value
 
     def to_dict(self):
         # type: () -> Dict[str, object]
